@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -208,7 +208,7 @@
 #define GIP_MOTOR_LEFT_IMPULSE (1u << 3)
 #define GIP_MOTOR_ALL 0xF
 
-/* Extended Comand constants */
+/* Extended Command constants */
 #define GIP_EXTCMD_GET_CAPABILITIES 0x00
 #define GIP_EXTCMD_GET_TELEMETRY_DATA 0x01
 #define GIP_EXTCMD_GET_SERIAL_NUMBER 0x04
@@ -809,7 +809,7 @@ static void GIP_MetadataFree(GIP_Metadata *metadata)
     SDL_free(metadata->device.hid_descriptor);
 
     SDL_free(metadata->message_metadata);
-    SDL_memset(metadata, 0, sizeof(*metadata));
+    SDL_zerop(metadata);
 }
 
 static bool GIP_ParseDeviceMetadata(GIP_Metadata *metadata, const Uint8 *bytes, int num_bytes, int *offset)
