@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -32,8 +32,6 @@
 /* Define this if you want to log all packets from the controller */
 /*#define DEBUG_HORI_PROTOCOL*/
 
-#define LOAD16(A, B) (Sint16)((Uint16)(A) | (((Uint16)(B)) << 8))
-
 enum
 {
     SDL_GAMEPAD_BUTTON_HORI_QAM = 11,
@@ -51,6 +49,8 @@ typedef struct
     Uint8 last_state[USB_PACKET_LENGTH];
     Uint64 sensor_ticks;
     Uint32 last_tick;
+    Uint64 simulated_sensor_step_ns;
+    Uint64 simulated_sensor_time_stamp;
     bool wireless;
     bool serial_needs_init;
 } SDL_DriverSteamHori_Context;
@@ -126,9 +126,13 @@ static bool HIDAPI_DriverSteamHori_OpenJoystick(SDL_HIDAPI_Device *device, SDL_J
         HIDAPI_DriverSteamHori_UpdateDevice(device);
     }
 
-    SDL_PrivateJoystickAddSensor(joystick, SDL_SENSOR_GYRO, 250.0f);
-    SDL_PrivateJoystickAddSensor(joystick, SDL_SENSOR_ACCEL, 250.0f);
+    const float sensorupdaterate = ctx->wireless ? 120.0f : 250.0f;
 
+    SDL_PrivateJoystickAddSensor(joystick, SDL_SENSOR_GYRO, sensorupdaterate);
+    SDL_PrivateJoystickAddSensor(joystick, SDL_SENSOR_ACCEL, sensorupdaterate);
+
+    const Uint64 sensorupdatestep_ms = ctx->wireless ? 8333 : 4000; // Equivalent to 120hz / 250hz respectively
+    ctx->simulated_sensor_step_ns = SDL_US_TO_NS(sensorupdatestep_ms);
     return true;
 }
 
@@ -313,7 +317,11 @@ static void HIDAPI_DriverSteamHori_HandleStatePacket(SDL_Joystick *joystick, SDL
         ctx->sensor_ticks += delta;
 
         /* Sensor timestamp is in 1us units, but there seems to be some issues with the values reported from the device */
-        sensor_timestamp = timestamp; // if the values were good we would call SDL_US_TO_NS(ctx->sensor_ticks);
+        // sensor_timestamp = timestamp; // if the values were good we would call SDL_US_TO_NS(ctx->sensor_ticks);
+
+        /* New approach - simulate a fixed rate of 250hz (from observation). This reduces stutter from dropped/racing bluetooth packets.*/
+        ctx->simulated_sensor_time_stamp += ctx->simulated_sensor_step_ns;
+        sensor_timestamp = ctx->simulated_sensor_time_stamp;
 
         const float accelScale = SDL_STANDARD_GRAVITY * 8 / 32768.0f;
         const float gyroScale = DEG2RAD(2048);
