@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -29,8 +29,8 @@
 
 struct SDL_VideoData
 {
-    int top_display;
-    int touch_display;
+    SDL_DisplayID top_display;
+    SDL_DisplayID touch_display;
 };
 
 struct SDL_WindowData
