@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -63,6 +63,8 @@ struct SDL_WindowData
                     struct xdg_positioner *xdg_positioner;
                 } popup;
             };
+
+            Uint32 serial;
         } xdg;
     } shell_surface;
     enum
@@ -127,7 +129,7 @@ struct SDL_WindowData
     char *app_id;
     double scale_factor;
 
-    Wayland_SHMBuffer *icon_buffers;
+    struct wl_buffer **icon_buffers;
     int icon_buffer_count;
 
     // Keyboard, pointer, and touch focus refcount.
@@ -203,7 +205,7 @@ struct SDL_WindowData
     bool suspended;
     bool resizing;
     bool active;
-    bool drop_interactive_resizes;
+    bool pending_config_ack;
     bool is_fullscreen;
     bool fullscreen_exclusive;
     bool drop_fullscreen_requests;
